
import java.util.*;
import java.io.*;

public class tombraider_font
{
   public static void main(String[] args) throws Exception
   {
      PrintWriter out = new PrintWriter(System.out);
      new tombraider_font(new FastScanner(System.in), out);
      out.close();
   }

   int N, M, numGars;
   char[][] grid;
   int[][] id;

   int[] dr = {-1, 0, 1, 0};
   int[] dc = {0, -1, 0, 1};

   int trace(int i, int j, int dir)
   {
      //System.out.printf("========%n");
      while (true)
      {
         i += dr[dir];
         j += dc[dir];
         //System.out.printf("%d %d%n", i, j);

         if (i < 0 || j < 0 || i >= N || j >= M)
            return -1;
         if (grid[i][j] == '#')
            return -2;
      
         if (grid[i][j] == 'H' || grid[i][j] == 'V')
         {
            return (dir&1)*numGars + id[i][j];
         }

         if (grid[i][j] == '/')
         {
            //System.out.printf("%d -- / --> %d%n", dir, dir ^ 3);
            dir ^= 3;
         }
         else if (grid[i][j] == '\\')
         {
            //System.out.printf("%d -- \\ --> %d%n", dir, dir ^ 1);
            dir ^= 1;
         }
      }
   }

   public tombraider_font(FastScanner in, PrintWriter out)
   {
      N = in.nextInt();
      M = in.nextInt();

      grid = new char[N][];
      for (int i=0; i<N; i++)
         grid[i] = in.next().toCharArray();
   
      numGars = 0;
      id = new int[N][M];
      for (int[] ii : id)
         Arrays.fill(ii, -1);
      for (int i=0; i<N; i++)
      {
         for (int j=0; j<M; j++)
         {
            if (grid[i][j] == 'V' || grid[i][j] == 'H')
            {
               id[i][j] = numGars;
               numGars++;
            }
         }
      }

      int[] costFor = new int[numGars*2];
      for (int i=0; i<N; i++)
      {
         for (int j=0; j<M; j++)
         {
            if (grid[i][j] == 'V' || grid[i][j] == 'H')
            {
               costFor[id[i][j]] = grid[i][j] == 'V' ? 1 : 0;
               costFor[id[i][j]+numGars] = 1 - costFor[id[i][j]];
            }
         }
      }

      ArrayList<Integer>[] adj = new ArrayList[numGars*2];
      for (int i=0; i<2*numGars; i++)
         adj[i] = new ArrayList<>();

      for (int i=0; i<numGars; i++)
      {
         int j = i + numGars;
         adj[i].add(j);
         adj[j].add(i);
      }

      // HHHHHVVVVV
      boolean[] isBad = new boolean[numGars*2];
      for (int i=0; i<N; i++)
      {
         for (int j=0; j<M; j++) if (id[i][j] >= 0)
         {
            //System.out.printf("Trace from %d %d%n", i, j);
            for (int dir=0; dir<4; dir++)
            {
               int a = id[i][j] + ((dir+1)&1) * numGars;
               int b = trace(i, j, dir);
               if (b == -2)
               {
                  //System.out.printf("%d %d %d is bad%n", i, j, dir);
                  isBad[a] = true;
               }
               else if (b >= 0)
               {
                  //System.out.printf("%d (%d) -- %d (%d)%n", a%numGars, a, b%numGars, b);
                  adj[a].add(b);
                  adj[b].add(a);
               }
            }
         }
      }

      ArrayDeque<Integer> q = new ArrayDeque<>();
      int[] color = new int[2*numGars];
      Arrays.fill(color, -1);

      int res = 0;
      boolean hasConflict = false;
      for (int i=0; i<numGars; i++)
      {
         if (color[i] != -1)
            continue;
         
         boolean[] blocked = new boolean[2];
         int[] costs = new int[2];
         q.add(i); 
         color[i] = 0;

         while (q.size() > 0)
         {
            int x = q.poll();
            if (isBad[x])
               blocked[color[x]] = true;
            costs[color[x]] += costFor[x];

            for (int y : adj[x])
            {
               if (color[y] == -1)
               {
                  color[y] = 1-color[x];
                  q.add(y);
               }

               if (color[y] != 1-color[x])
                  hasConflict = true;
            }
         }

         int rr = Integer.MAX_VALUE;
         if (!blocked[0])
            rr = Math.min(rr, costs[0]);
         if (!blocked[1])
            rr = Math.min(rr, costs[1]);
         if (rr == Integer.MAX_VALUE)
            hasConflict = true;
         res += rr;
         //System.out.println(Arrays.toString(color));
      }
  
      out.println(hasConflict ? -1 : res);
   }
}

class FastScanner
{
   private InputStream stream;
   private byte[] buf = new byte[1024];
   private int curChar;
   private int numChars;
    
   public FastScanner(InputStream stream)
   {
      this.stream = stream;
   }
    
   int read()
   {
      if (numChars == -1)
         throw new InputMismatchException();
      if (curChar >= numChars)
      {
         curChar = 0;
         try
         {
            numChars = stream.read(buf);
         } 
         catch (IOException e) 
         {
            throw new InputMismatchException();
         }
         
         if (numChars <= 0)
            return -1;
      }
      return buf[curChar++];
   }
    
   boolean isSpaceChar(int c)
   {
      return c==' '||c=='\n'||c=='\r'||c=='\t'||c==-1;
   }
   
   boolean isEndline(int c)
   {
      return c=='\n'||c=='\r'||c==-1;
   }
   
   int nextInt()
   {
      return Integer.parseInt(next());
   }
   
   long nextLong()
   {
      return Long.parseLong(next());
   }
   
   double nextDouble()
   {
      return Double.parseDouble(next());
   }
   
   String next()
   {
      int c = read();
      while (isSpaceChar(c))
         c = read();
      StringBuilder res = new StringBuilder();
      do
      {
         res.appendCodePoint(c);
         c = read();
      } while(!isSpaceChar(c));
      return res.toString();
   }
   
   String nextLine()
   {
      int c = read();
      while (isEndline(c))
         c = read();
      
      StringBuilder res = new StringBuilder();
      do
      {
         res.appendCodePoint(c);
         c = read();
      } while(!isEndline(c));
      return res.toString();
   }
}
